# Changelog

## [Unreleased][]

[Unreleased]: https://github.com/chaostoolkit/chaosplatform-experiment/compare/0.2.0...HEAD

## [0.2.0][] - 2019-01-14

[0.2.0]: https://github.com/chaostoolkit/chaosplatform-experiment/compare/0.1.2...0.2.0

### Changed

-  Moved from dotenv to toml for greater flexibility and readability

## [0.1.2][] - 2019-01-12

[0.1.2]: https://github.com/chaostoolkit/chaosplatform-experiment/compare/0.1.1...0.1.2

### Changed

-  Pin only a minimum version of each dependency for composability

## [0.1.1][] - 2019-01-10

[0.1.1]: https://github.com/chaostoolkit/chaosplatform-experiment/compare/0.1.0...0.1.0

### Changed

-   Set minimal Python version to 3.6

## [0.1.0][] - 2019-01-10

[0.1.0]: https://github.com/chaostoolkit/chaosplatform-experiment/tree/0.1.0

### Added

-   Initial release